Coverage for rancidcmd: 97%

# Coverage for rancidcmd : 97%

## 61 statements 59 run 2 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 | # -*- coding: utf-8 -*- """RancidCmd.""" from subprocess import Popen from subprocess import PIPE from os.path import expanduser import os import re import stat class RancidCmd(object): """Class RancidCmd. Attributes: :login (str): RANCID login command(clogin, jlogin, etc). :user (str): Login username. :password (str): Login password. :address (str): Host name or ip address. :enable_password (str, optional): Enable password for clogin. Default is None. :option(int, optional): Option example: '-d -x "commands.txt"'. Default is None. :timeout(int, optional): Timeout value(seconds). Default is 10 seconds. :encoding(str, optional): Encoding type. Default is 'utf-8'. Using example: * Please see README. https://github.com/mtoshi/rancidcmd/blob/master/README.rst * Sample code. https://github.com/mtoshi/rancidcmd/blob/master/samples/sample.py """ def __init__(self, **kwargs): """Constructor. Args: :login (str): RANCID login command(clogin, jlogin, etc). :user (str): Login username. :password (str): Login password. :address (str): Host name or ip address. :enable_password (str, optional): Enable password for clogin. Default is None. :option(int, optional): Option example: '-d -x "commands.txt"'. Default is None. :timeout(int, optional): Timeout value(seconds). Default is 10 seconds. :encoding(str, optional): Encoding type. Default is 'utf-8'. """ self.login = kwargs['login'] self.user = kwargs['user'] self.password = kwargs['password'] self.address = kwargs['address'] self.enable_password = kwargs.get('enable_password', None) self.timeout = kwargs.get('timeout', 10) self.option = kwargs.get('option', None) self.encoding = 'utf-8' RancidCmd.check_cloginrc() def is_option_x(self): """Check -x option. "-c" gets commands from command-line. "-x" gets commnads from file. These are for command option and exclusive. If "-x" option is specified, then "-c" command is ignored. """ if self.option: pat = re.compile(r'(\s+)?-x\s+') if pat.search(self.option): return True return False def generate_cmd(self, command): """Generate command. Args: :command (str): Example is "show version". Returns: :str: Return the command string. If there is the "enable_password". :: 'xlogin -t 10 -u admin -p password -e enable_password -c "show version"' If you have not set the "enable_password". :: 'xlogin -t 10 -u admin -p password -c "show version"' """ if self.is_option_x(): command = '' else: command = '-c "%s"' % command option = '' if self.option: option = self.option enable_password = '' if self.enable_password: enable_password = '-e "%s"' % self.enable_password return '%s -t %s -u "%s" -p "%s" %s %s %s %s' % ( self.login, self.timeout, self.user, self.password, enable_password, option, command, self.address) def decode_bytes(self, byte_data): """Change string with encoding setting. Args: :byte_data (bytes): Popen output. """ return byte_data.decode(self.encoding) def cmd_exec(self, command): """Login and command execution. Args: :command (str): Command for execution. Returns: :dict: Example is below. :: { 'std_err': '', 'std_out': '', } """ proc = Popen(command, shell=True, stdout=PIPE, stderr=PIPE) std_out, std_err = proc.communicate() return {'std_out': self.decode_bytes(std_out), 'std_err': self.decode_bytes(std_err)} def show(self, command): """Execute command string check. Args: :command (str): Example is "show version". Returns: :str: Return the command string. """ print(self.generate_cmd(command)) def execute(self, command): """Command execution. Args: :command (str): Example is "show version". Returns: :dict: Example is below. :: { 'std_err': '', 'std_out': '', } """ cmd = self.generate_cmd(command) return self.cmd_exec(cmd) @staticmethod def touch(path): """Make empty file. Args: :path (str): File path. """ try: with open(path, 'a'): os.utime(path, None) os.chmod(path, stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR) except: print('[error] Could not write "%s".' % path) raise @staticmethod def check_cloginrc(name='.cloginrc'): """Check rancid settings file. Note: If RANCID settings file is not exists, then make empty settings file. Args: :name (str, optional): RANCID settings file name. Default is ".cloginrc". Returns: :str: RANCID settings file path. """ home = expanduser("~") path = os.path.join(home, name) if not os.path.isfile(path): RancidCmd.touch(path) return path